@@ -3,7 +3,7 @@
  * The University of Illinois/NCSA
  * Open Source License (NCSA)
  *
- * Copyright (c) 2019, Advanced Micro Devices, Inc.
+ * Copyright (c) 2025, Advanced Micro Devices, Inc.
  * All rights reserved.
  *
  * Developed by:
@@ -517,7 +517,7 @@ int GetProcessInfoForPID(uint32_t pid, rsmi_process_info_t *proc,
       cu_count += kfd_node_map[gpu_id]->cu_count();
     }
     else {
-      // Some GFX revisions do not provide cu_occupancy debugfs method 
+      // Some GFX revisions do not provide cu_occupancy debugfs method
       // which may cause ENOENT
       proc->cu_occupancy = CU_OCCUPANCY_INVALID;
       cu_count = 0;
@@ -881,7 +881,7 @@ int KFDNode::get_used_memory(uint64_t* used) {
       return 1;
   }
   struct kfd_ioctl_get_available_memory_args mem = {0, 0, 0};
-  mem.gpu_id = gpu_id_;
+  mem.gpu_id = static_cast<uint32_t>(gpu_id_);
   if (ioctl(kfd_fd, AMDKFD_IOC_AVAILABLE_MEMORY , &mem) != 0) {
     close(kfd_fd);
     return 1;
@@ -1051,6 +1051,7 @@ int KFDNode::get_node_id(uint32_t *node_id) {
   int ret = 0;
   std::string nodeid_path = "/sys/class/kfd/kfd/topology/nodes/"
     + std::to_string(this->node_indx_);
+  *node_id = this->node_indx_;
   ss << __PRETTY_FUNCTION__
      << " | File: " << nodeid_path
      << " | Read node #: " << std::to_string(this->node_indx_)
@@ -1058,7 +1059,6 @@ int KFDNode::get_node_id(uint32_t *node_id) {
      << " | Return: "
      << getRSMIStatusString(amd::smi::ErrnoToRsmiStatus(ret), false)
      << " | ";
-  *node_id = this->node_indx_;
   LOG_DEBUG(ss);
   return ret;
 }
