@@ -5,7 +5,7 @@
  * The University of Illinois/NCSA
  * Open Source License (NCSA)
  *
- * Copyright (c) 2020-2024, Advanced Micro Devices, Inc.
+ * Copyright (c) 2020-2025, Advanced Micro Devices, Inc.
  * All rights reserved.
  *
  * Developed by:
@@ -127,7 +127,7 @@ void TestGpuMetricsRead::Run(void) {
         IF_VERB(STANDARD) {
           std::cout << "\t**" <<
           "Not supported on this machine" << std::endl;
-          return;
+          continue;
         }
       }
     } else {
@@ -269,6 +269,12 @@ void TestGpuMetricsRead::Run(void) {
                     amd::smi::make_ostream_joiner(&std::cout, ", "));
           std::cout << std::dec << "]\n";
 
+          std::cout << std::dec << "xgmi_link_status= [";
+          std::copy(std::begin(smu.xgmi_link_status),
+                    std::end(smu.xgmi_link_status),
+                    amd::smi::make_ostream_joiner(&std::cout, ", "));
+          std::cout << std::dec << "]\n";
+
           // Voltage (mV)
           std::cout << "voltage_soc = " << std::dec << smu.voltage_soc << "\n";
           std::cout << "voltage_gfx = " << std::dec << smu.voltage_gfx << "\n";
@@ -284,6 +290,9 @@ void TestGpuMetricsRead::Run(void) {
           std::cout << "pcie_bandwidth_acc=" << std::dec << smu.pcie_bandwidth_acc << "\n";
           std::cout << "pcie_bandwidth_inst=" << std::dec << smu.pcie_bandwidth_inst << "\n";
 
+          // VRAM max bandwidth at max memory clock
+          std::cout << "vram_max_bandwidth=" << std::dec << smu.vram_max_bandwidth << "\n";
+
           // Counts
           std::cout << "pcie_l0_to_recov_count_acc= " << std::dec << smu.pcie_l0_to_recov_count_acc
                     << "\n";
@@ -360,6 +369,61 @@ void TestGpuMetricsRead::Run(void) {
             xcp++;
           }
 
+          xcp = 0;
+          std::cout << std::dec << "xcp_stats.gfx_below_host_limit_acc = \n";  // new for 1.7
+          for (auto& row : smu.xcp_stats) {
+            std::cout << "XCP[" << xcp << "] = " << "[ ";
+            std::copy(std::begin(row.gfx_below_host_limit_acc),
+                    std::end(row.gfx_below_host_limit_acc),
+                    amd::smi::make_ostream_joiner(&std::cout, ", "));
+            std::cout << " ]\n";
+            xcp++;
+          }
+          // new for gpu metrics v1.8
+          xcp = 0;
+          std::cout << std::dec << "xcp_stats.gfx_below_host_limit_ppt_acc = \n";
+          for (auto& row : smu.xcp_stats) {
+            std::cout << "XCP[" << xcp << "] = " << "[ ";
+            std::copy(std::begin(row.gfx_below_host_limit_ppt_acc),
+                    std::end(row.gfx_below_host_limit_ppt_acc),
+                    amd::smi::make_ostream_joiner(&std::cout, ", "));
+            std::cout << " ]\n";
+            xcp++;
+          }
+
+          xcp = 0;
+          std::cout << std::dec << "xcp_stats.gfx_below_host_limit_thm_acc = \n";
+          for (auto& row : smu.xcp_stats) {
+            std::cout << "XCP[" << xcp << "] = " << "[ ";
+            std::copy(std::begin(row.gfx_below_host_limit_thm_acc),
+                    std::end(row.gfx_below_host_limit_thm_acc),
+                    amd::smi::make_ostream_joiner(&std::cout, ", "));
+            std::cout << " ]\n";
+            xcp++;
+          }
+
+          xcp = 0;
+          std::cout << std::dec << "xcp_stats.gfx_low_utilization_acc = \n";
+          for (auto& row : smu.xcp_stats) {
+            std::cout << "XCP[" << xcp << "] = " << "[ ";
+            std::copy(std::begin(row.gfx_low_utilization_acc),
+                    std::end(row.gfx_low_utilization_acc),
+                    amd::smi::make_ostream_joiner(&std::cout, ", "));
+            std::cout << " ]\n";
+            xcp++;
+          }
+
+          xcp = 0;
+          std::cout << std::dec << "xcp_stats.gfx_below_host_limit_total_acc = \n";
+          for (auto& row : smu.xcp_stats) {
+            std::cout << "XCP[" << xcp << "] = " << "[ ";
+            std::copy(std::begin(row.gfx_below_host_limit_total_acc),
+                    std::end(row.gfx_below_host_limit_total_acc),
+                    amd::smi::make_ostream_joiner(&std::cout, ", "));
+            std::cout << " ]\n";
+            xcp++;
+          }
+
           std::cout << "\n\n";
           std::cout << "\t ** -> Checking metrics with constant changes ** " << "\n";
           constexpr uint16_t kMAX_ITER_TEST = 10;
